Learn R Programming

ari (version 0.3.1)

ari_talk: Create spoken audio files

Description

A simple function for demoing how spoken text will sound.

Usage

ari_talk(paragraphs, output = tempfile(fileext = ".wav"),
  voice = "Joanna", service = "amazon")

Arguments

paragraphs

A vector strings that will be spoken by Amazon Polly.

output

A path to the audio file which will be created.

voice

The voice you want to use. See tts_voices for more information about what voices are available.

service

speech synthesis service to use, passed to tts

Value

A Wave output object, with the attribute outfile of the output file name.