A simple function for demoing how spoken text will sound.
ari_talk(paragraphs, output = tempfile(fileext = ".wav"),
voice = "Joanna", service = "amazon")A vector strings that will be spoken by Amazon Polly.
A path to the audio file which will be created.
The voice you want to use. See
tts_voices for more information
about what voices are available.
speech synthesis service to use,
passed to tts
A Wave output object, with the attribute outfile
of the output file name.